<?php

//this is spotless_days.php

//include the functions file
require_once('sunspot_data_functions.php');

//include charts.php to access the SendChartData function
require_once('charts.php');

//var_dump($_POST);


//if they are submitting
if($_POST['Submit']){

	//make sure we received all required vars
	if($start_month == '.' || $start_year == '.' || $end_month == '.' || $end_year == '.'){
		$error_message = 'Error: please provide all required info.';
	}

	//make sure they sent a valid month, year, and range
	else if(!isValidMonth($start_month) || !isValidMonth($end_month)){
		$error_message = 'Error: that is not a valid month.';
	}

	else if(!isValidYear($start_year) || !isValidYear($end_year)){
		$error_message = 'Error: that is not a valid year.';
	}
	
	//make sure their end date is later than the start date
	else if(!validateTimeSpan($start_month, $start_year, $end_month, $end_year)){
		$error_message = 'Error: your start date must be prior to your end date.';
	}
	
	//make sure they didn't enter an end date which is in the future
	//and thus not in the database
	else if(!validateEndDate($end_month, $end_year)){
		$error_message = 'Error: your end date is too far in the future.';
	}
	
	//make sure they didn't select a date span of 
	//more than 75 years, which seems to cause a timeout error with the chart
	else if(!validateTimeoutSpan($start_year, $end_year)){
		$error_message = 'Error: your date span must be 75 years or less.';
	}


	//else it was all good so proceed
	else{
	
		echo 'processing chart...<br>';
		
		//call our function select all the records from this 
		//date span into an assoc array of IDs and SunspotNumbers
		$ids_spots_assoc = getIDsSpotsAssoc($start_month, $start_year, $end_month, $end_year);
		
		//call our function to return the top five continuous
		//dates with SunspotNumber of zero in an array
		$continuous_spotdates_assoc = returnContinuousSpotDatesAssoc($ids_spots_assoc);
	}
}


?>
<html>
<head>
<title><?php echo $site_name; ?></title>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
<link rel="stylesheet" href="sunspot_charts_styles.css" type="text/css">
</head>

<body bgcolor="#FFFFFF" text="#000000">
<table width="100%" border="0" cellspacing="0" cellpadding="0" height="100%">
  <tr>
    <td>
      <div align="center"> 
        <form name="form1" method="post" action="<?php echo $PHP_SELF; ?>">
          <?php
		  
		  //if there was an error then display it
		  if($error_message){
		  
		  		echo "<table width='650' border='0' cellspacing='0' cellpadding='0'>
					<tr> 
					  <td class='errorMessageText'>$error_message</td>
					</tr>
				  </table>
				  <table width='650' border='0' cellspacing='0' cellpadding='0'>
					<tr> 
					  <td><img src='images/spacer.gif' width='10' height='6'></td>
					</tr>
				  </table>";
		  }
		  
		  ?>
          <?php
		  
		  //if there was an admin message then display it
		  if($admin_message){
		  
		  		echo "<table width='650' border='0' cellspacing='0' cellpadding='0'>
					<tr> 
					  <td class='errorMessageText'>$admin_message</td>
					</tr>
				  </table>
				  <table width='650' border='0' cellspacing='0' cellpadding='0'>
					<tr> 
					  <td><img src='images/spacer.gif' width='10' height='6'></td>
					</tr>
				  </table>";
		  }
		  
		  ?>
          <table width="800" border="0" cellspacing="0" cellpadding="0">
            <tr> 
              <td> 
                <select name="start_month" class="dropMenus">
                  <?php

							//if they are coming to this page for the first time
							//then show a menu label
							if(!$_POST['start_month'] || $_POST['start_month'] == '.'){
								echo "<option value='.' selected>Month</option>";
							}
							
							
							//this is our standard drop menu code
							foreach(range(1, 12) as $my_var){
							
								//if they submitted a month already then show
								//that as a preselected option
								if($my_var == $_POST['start_month']){
								
									//pad with a zero
									if($my_var < 10){
										$my_var = 0 . $my_var;
									}
								
									echo "<option value='$my_var' selected>$my_var</option>";
								}
						
								//else if its less than ten then pad it with a zero
								else{
								
									//pad with a zero
									if($my_var < 10){
										$my_var = 0 . $my_var;
									}
								  
									echo "<option value='$my_var'>$my_var</option>";
								}
							
							}
						  
						  ?>
                </select>
                <select name="start_year" class="dropMenus">
                  <?php
						  
							//if they are coming to this page for the first time
							//then show a menu label
							if(!$_POST['start_year'] || $_POST['start_year'] == '.'){
								echo "<option value='.' selected>Year</option>";
							}
							
							
							//this is our standard drop menu code
							foreach(range(1818, 2007) as $my_var){
							
								//if they submitted a year already then show
								//that as a preselected option
								if($my_var == $_POST['start_year']){
									echo "<option value='$my_var' selected>$my_var</option>";
								}
						
								//else if its less than ten then pad it with a zero
								else{
									echo "<option value='$my_var'>$my_var</option>";
								}
							
							}
						  
						  ?>
                </select>
                <table width="800" border="0" cellspacing="0" cellpadding="0">
                  <tr> 
                    <td><img src="images/spacer.gif" width="10" height="3"></td>
                  </tr>
                </table>
                <select name="end_month" class="dropMenus">
                  <?php

							//if they are coming to this page for the first time
							//then show a menu label
							if(!$_POST['end_month'] || $_POST['end_month'] == '.'){
								echo "<option value='.' selected>Month</option>";
							}
							
							
							//this is our standard drop menu code
							foreach(range(1, 12) as $my_var){
							
								//if they submitted a month already then show
								//that as a preselected option
								if($my_var == $_POST['end_month']){
								
									//pad with a zero
									if($my_var < 10){
										$my_var = 0 . $my_var;
									}
								
									echo "<option value='$my_var' selected>$my_var</option>";
								}
						
								//else if its less than ten then pad it with a zero
								else{
								
									//pad with a zero
									if($my_var < 10){
										$my_var = 0 . $my_var;
									}
								  
									echo "<option value='$my_var'>$my_var</option>";
								}
							
							}
						  
						  ?>
                </select>
                <select name="end_year" class="dropMenus">
                  <?php
						  
							//if they are coming to this page for the first time
							//then show a menu label
							if(!$_POST['end_year'] || $_POST['end_year'] == '.'){
								echo "<option value='.' selected>Year</option>";
							}
							
							
							//this is our standard drop menu code
							foreach(range(1818, 2007) as $my_var){
							
								//if they submitted a year already then show
								//that as a preselected option
								if($my_var == $_POST['end_year']){
									echo "<option value='$my_var' selected>$my_var</option>";
								}
						
								//else if its less than ten then pad it with a zero
								else{
									echo "<option value='$my_var'>$my_var</option>";
								}
							
							}
						  
						  ?>
                </select>
                <table width="800" border="0" cellspacing="0" cellpadding="0">
                  <tr> 
                    <td><img src="images/spacer.gif" width="10" height="5"></td>
                  </tr>
                </table>
                <?php
				
				//if the checkbox was selected then show it preselected
				if($view_sunspotnumbers_checkbox == 'yes'){
					echo "<input type='checkbox' name='view_sunspotnumbers_checkbox' value='yes' checked>";
				}
				
				//else show it unselected
				else{
					echo "<input type='checkbox' name='view_sunspotnumbers_checkbox' value='yes'>";
				}
				
				?>
                <span class="viewSunspotNumbersCheckboxText">View complimentary 
                sunspot numbers </span> 
                <table width="800" border="0" cellspacing="0" cellpadding="0">
                  <tr> 
                    <td><img src="images/spacer.gif" width="10" height="3"></td>
                  </tr>
                </table>
                <input type="submit" name="Submit" value="Submit">
              </td>
            </tr>
          </table>
          <table width="800" border="0" cellspacing="0" cellpadding="0">
            <tr> 
              <td><img src="images/spacer.gif" width="10" height="10"></td>
            </tr>
          </table>
          <table width="800" border="0" cellspacing="0" cellpadding="0">
            <tr> 
              <td>
			<?php
			
			//we'll only show the chart if there were no errors
			//the timeout parameter should ensure the flash chart doesn't timeout
			if(!$error_message){
				echo InsertChart ( "charts.swf?timeout=9999", "charts_library", "generate_spotless_chart.php?start_month=$start_month&start_year=$start_year&end_month=$end_month&end_year=$end_year&view_sunspotnumbers_checkbox=$view_sunspotnumbers_checkbox", 800, 500 );
			}
			
			?>
			</td>
            </tr>
          </table>
        </form>
        <table width="800" border="0" cellspacing="0" cellpadding="0">
          <tr> 
            <td><img src="images/spacer.gif" width="10" height="10"></td>
          </tr>
        </table>
        <table width="800" border="0" cellspacing="0" cellpadding="0">
          <tr> 
            <td class="standardText">
              <?php
			  
			  ///IF THEY'VE SUBMITTED
			  //call our function to get the total number
			  //of spotless days for this datespan
			  if($_POST['Submit']){
				  
				  $sum_spotless_days = calculateAllSpotlessDays($start_month, $start_year, $end_month, $end_year);
				  
				  //display the sum of spotless days in red
				  echo "Total days with no sunspots in date span: <font color='red'>$sum_spotless_days</font>";
			  }
			  
			  ?>
			  </td>
          </tr>
        </table>
        <table width="800" border="0" cellspacing="0" cellpadding="0">
          <tr> 
            <td><img src="images/spacer.gif" width="10" height="10"></td>
          </tr>
        </table>
        <table width="800" border="0" cellspacing="0" cellpadding="0">
          <tr> 
            <td class="standardText"> 
              <?php
			  
			  ///IF THEY'VE SUBMITTED
			  //display the top five elements from our assoc array
			  //of dates and number of spotless days
			  if($_POST['Submit']){
			  
			  		echo 'Longest continuous spotless spans:<br>';
			  
			  		//initialize a counter
					$i = 0;
				
					foreach($continuous_spotdates_assoc as $my_key => $my_val){
					
						if($i < 5){
						
							echo "$my_val spotless days starting " . getDateFromRecordID($my_key) . '<br>';
						}
						
						//increment the counter
						$i++;
					}
				  
				}
			  
			  ?>
            </td>
          </tr>
        </table>
      </div>
    </td>
  </tr>
</table>
</body>
</html>
